# 拉取请求

代码贡献开发流程如下：

1. 开发者需先 [fork](https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/working-with-forks/fork-a-repo) [上游](https://github.com/NVIDIA/GenerativeAIExamples/tree/main) 开源生成式 AI 仓库。
2. Git 克隆 fork 后的仓库，并将更改推送到个人 fork。
3. 当代码更改已在 fork 上准备好评审时，可发起 Pull Request (PR)，请求将 fork 分支的更改合并到上游选定分支。
4. 由于尚未建立 CI/CD 流程，PR 仅在开发者和/或仓库所有者手动充分测试后才会被接受并关闭相关 issue。

## 签署你的工作

所有贡献者必须在提交时“签署”自己的提交。这表示该贡献是你的原创作品，或你有权按相同或兼容许可提交。

任何未签署的提交将不被接受。
签署提交请使用 `--signoff`（或 `-s`）参数：

`$ git commit -s -m "添加新功能。"`
这将在提交信息后附加如下内容：

Signed-off-by: Your Name <your@email.com>

## 开发者原始证书

版本 1.1

版权所有 (C) 2004, 2006 Linux 基金会及其贡献者。

允许任何人复制和分发本许可文档的原文，但不允许更改。

开发者原始证书 1.1

通过为本项目做出贡献，我声明：

(a) 该贡献完全或部分由我创作，我有权按文件中注明的开源许可提交；或
(b) 该贡献基于我所知的适当开源许可下的先前作品，我有权按该许可提交修改后的作品（无论全部或部分），并按文件中注明的开源许可（除非允许提交其他许可）；或
(c) 该贡献由其他人直接提供给我，并已声明 (a)、(b) 或 (c)，且我未做修改。
(d) 我理解并同意本项目及贡献是公开的，贡献记录（包括所有个人信息及签署信息）将被永久保存，并可按项目或相关开源许可分发
